==> lumi_2.4.0.zip: lumi/doc/IlluminaAnnotation.R <==
###################################################
### chunk number 1: Loading required libraries
###################################################
#line 46 "IlluminaAnnotation.Rnw"
library(lumi)
library(annotate)
# library(lumiHumanAll.db)


###################################################
### chunk number 2: 
###################################################
#line 63 "IlluminaAnnotation.Rnw"
## provide an arbitrary nucleotide sequence as an example 
seq <- 'ACGTAAATTTCAGTTTAAAACCCCCCG'
## create a nuID for it
id <- seq2id(seq)
print(id)


###################################################
### chunk number 3: 
###################################################
#line 73 "IlluminaAnnotation.Rnw"
id2seq(id)


###################################################
### chunk number 4: 
###################################################
#line 79 "IlluminaAnnotation.Rnw"
is.nuID(id)


###################################################
### chunk number 5: 
###################################################
#line 84 "IlluminaAnnotation.Rnw"
is.nuID('adfqeqe')


###################################################
### chunk number 6: 
###################################################
#line 114 "IlluminaAnnotation.Rnw"
  if (require(lumiHumanIDMapping))
 	 lumiHumanIDMapping()


###################################################
### chunk number 7: 
###################################################
#line 120 "IlluminaAnnotation.Rnw"
  ## Load Illumina example data in lumi package
  data(example.lumi)
  ## Match the chip information of this example data
  if (require(lumiHumanIDMapping))
	getChipInfo(example.lumi, species='Human')


###################################################
### chunk number 8: 
###################################################
#line 146 "IlluminaAnnotation.Rnw"
  if (require(lumiHumanIDMapping))
	lumiHumanIDMapping_nuID()


###################################################
### chunk number 9: 
###################################################
#line 152 "IlluminaAnnotation.Rnw"
     nuIDs <- featureNames(example.lumi)
      ## return all mapping information
    if (require(lumiHumanIDMapping))
          nuID2RefSeqID(nuIDs[1:10], lib.mapping='lumiHumanIDMapping')


###################################################
### chunk number 10: 
###################################################
#line 160 "IlluminaAnnotation.Rnw"
   if (require(lumiHumanIDMapping))
        nuID2EntrezID(nuIDs[1:10], lib.mapping='lumiHumanIDMapping')


###################################################
### chunk number 11: 
###################################################
#line 166 "IlluminaAnnotation.Rnw"
   if (require(lumiHumanIDMapping)) {
        mappingInfo <- nuID2RefSeqID(nuIDs[1:10], lib.mapping='lumiHumanIDMapping', returnAllInfo =TRUE)
        head(mappingInfo)
   }


###################################################
### chunk number 12: 
###################################################
#line 184 "IlluminaAnnotation.Rnw"
     data(example.lumi)
     nuIDs <- featureNames(example.lumi)
     if (require(lumiHumanAll.db))
     	getSYMBOL(nuIDs[1:3], 'lumiHumanAll.db')


###################################################
### chunk number 13: 
###################################################
#line 192 "IlluminaAnnotation.Rnw"
     if (require(lumiHumanAll.db))
    	 getEG(nuIDs[1:3], 'lumiHumanAll.db')


###################################################
### chunk number 14: 
###################################################
#line 198 "IlluminaAnnotation.Rnw"
     if (require(lumiHumanAll.db)) {
 	 goInfo <- getGO(nuIDs[1], 'lumiHumanAll.db')
	 goInfo[[1]][[1]]
     }


###################################################
### chunk number 15: 
###################################################
#line 206 "IlluminaAnnotation.Rnw"
     if (require(lumiHumanAll.db))
     	lookUp(nuIDs[1:3], "lumiHumanAll.db", what="SYMBOL")


###################################################
### chunk number 16: 
###################################################
#line 212 "IlluminaAnnotation.Rnw"
     if (require(lumiHumanAll.db))
	ls('package:lumiHumanAll.db')

==> lumi_2.14.2.zip: lumi/doc/IlluminaAnnotation.R <==
### R code from vignette source 'IlluminaAnnotation.Rnw'

###################################################
### code chunk number 1: Loading required libraries
###################################################
library(lumi)
library(annotate)
# library(lumiHumanAll.db)


###################################################
### code chunk number 2: IlluminaAnnotation.Rnw:67-72
###################################################
## provide an arbitrary nucleotide sequence as an example 
seq <- 'ACGTAAATTTCAGTTTAAAACCCCCCG'
## create a nuID for it
id <- seq2id(seq)
print(id)


###################################################
### code chunk number 3: IlluminaAnnotation.Rnw:77-78
###################################################
id2seq(id)


###################################################
### code chunk number 4: IlluminaAnnotation.Rnw:83-84
###################################################
is.nuID(id)


###################################################
### code chunk number 5: IlluminaAnnotation.Rnw:88-89
###################################################
is.nuID('adfqeqe')


###################################################
### code chunk number 6: IlluminaAnnotation.Rnw:118-120
###################################################
  if (require(lumiHumanIDMapping))
 	 lumiHumanIDMapping()


###################################################
### code chunk number 7: IlluminaAnnotation.Rnw:124-129
###################################################
  ## Load Illumina example data in lumi package
  data(example.lumi)
  ## Match the chip information of this example data
  if (require(lumiHumanIDMapping))
	getChipInfo(example.lumi, species='Human')


###################################################
### code chunk number 8: IlluminaAnnotation.Rnw:150-152
###################################################
  if (require(lumiHumanIDMapping))
	lumiHumanIDMapping_nuID()


###################################################
### code chunk number 9: IlluminaAnnotation.Rnw:156-160
###################################################
     nuIDs <- featureNames(example.lumi)
      ## return all mapping information
    if (require(lumiHumanIDMapping))
          nuID2RefSeqID(nuIDs[1:10], lib.mapping='lumiHumanIDMapping')


###################################################
### code chunk number 10: IlluminaAnnotation.Rnw:164-166
###################################################
   if (require(lumiHumanIDMapping))
        nuID2EntrezID(nuIDs[1:10], lib.mapping='lumiHumanIDMapping')


###################################################
### code chunk number 11: IlluminaAnnotation.Rnw:170-174
###################################################
   if (require(lumiHumanIDMapping)) {
        mappingInfo <- nuID2RefSeqID(nuIDs[1:10], lib.mapping='lumiHumanIDMapping', returnAllInfo =TRUE)
        head(mappingInfo)
   }


###################################################
### code chunk number 12: IlluminaAnnotation.Rnw:188-192
###################################################
     data(example.lumi)
     nuIDs <- featureNames(example.lumi)
     if (require(lumiHumanAll.db))
     	getSYMBOL(nuIDs[1:3], 'lumiHumanAll.db')


###################################################
### code chunk number 13: IlluminaAnnotation.Rnw:196-198
###################################################
     if (require(lumiHumanAll.db))
    	 getEG(nuIDs[1:3], 'lumiHumanAll.db')


###################################################
### code chunk number 14: IlluminaAnnotation.Rnw:202-206
###################################################
     if (require(lumiHumanAll.db)) {
 	 goInfo <- getGO(nuIDs[1], 'lumiHumanAll.db')
	 goInfo[[1]][[1]]
     }


###################################################
### code chunk number 15: IlluminaAnnotation.Rnw:210-212
###################################################
     if (require(lumiHumanAll.db))
     	lookUp(nuIDs[1:3], "lumiHumanAll.db", what="SYMBOL")


###################################################
### code chunk number 16: IlluminaAnnotation.Rnw:216-218
###################################################
     if (require(lumiHumanAll.db))
	ls('package:lumiHumanAll.db')
